ModuloCheckpointKeeper
======================

.. currentmodule:: pykeen.checkpoints

.. autoclass:: ModuloCheckpointKeeper
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ModuloCheckpointKeeper.divisor

   .. rubric:: Methods Summary

   .. autosummary::

      ~ModuloCheckpointKeeper.__call__

   .. rubric:: Attributes Documentation

   .. autoattribute:: divisor

   .. rubric:: Methods Documentation

   .. automethod:: __call__
